@@ -1,6 +1,7 @@
 import os
 import collections.abc
 
+
 class ConfigEnv:
     def __init__(self) -> None:
         self.python_env = os.getenv("PYTHON_ENV")
@@ -35,7 +36,7 @@ class ConfigEnv:
 
     def __run(self):
         self.config = {}
-        dir = os.getcwd()+"/config"
+        dir = os.getcwd() + "/configenv"
         files = os.listdir(dir)
         filenames = []
         for file in files:
@@ -43,9 +44,7 @@ class ConfigEnv:
             if os.stat(path).st_size != 0:
                 filename = file.split(".")[0].replace("-", "_") + "_config"
                 filenames.append(filename)
-                print("filename: "+filename)
-                print(eval(open(path).read()))
-                exec(filename +" = eval(open(path).read())")
+                exec(filename + "= eval(open(path).read())")
 
         if self.python_env == None or "DEFAULT":
             if "default.json" in files:
@@ -54,11 +53,11 @@ class ConfigEnv:
                 raise ValueError("Missing config file default.json")
 
         if self.python_env not in [None, "DEFAULT"]:
-            if self.python_env.lower().replace("-","_") +".json" in files:
+            if (self.python_env.lower().replace('-','_')+".json") in files:
                 env_name = self.python_env.lower() + "_config"
                 self.config = self.__update_dictionary(self.config, eval(env_name))
             else:
-                raise ValueError("Missing config file"+ self.python_env.lower()+".json")
+                raise ValueError("Missing config file"+ self.python_env.lower()+ ".json")
 
         if "custom_environment_variables.json" in files:
             custom_config = self.__evaluate_environment_variables(
